Accrue.Credo.NoRawStatusAccess (accrue v0.3.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Never gate features on raw subscription.status. Use Accrue.Billing.Subscription predicates (active?/1, canceling?/1, canceled?/1, past_due?/1, paused?/1, trialing?/1) or Accrue.Billing.Query fragments. Enforces BILL-05.

Check-Specific Parameters

There are no specific parameters for this check.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.